@@ -5,20 +5,27 @@ use warnings;
 use base qw(Log::Dispatch::Output);
 use Test::More qw();
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 sub new {
     my $proto = shift;
     my $class = ref($proto) || $proto;
     my $self  = bless { }, $class;
-    $self->_basic_init(@_);
+    my %opts  = @_;
+
+    $self->_basic_init(%opts);
+
+    $self->{as_note} = 1 if ($opts{as_note});
+
     return $self;
 }
 
 sub log_message {
     my $self = shift;
     my %p    = @_;
-    Test::More::diag($p{message});
+    $self->{as_note}
+        ? Test::More::note($p{message})
+        : Test::More::diag($p{message});
 }
 
 1;
@@ -33,7 +40,7 @@ Log::Dispatch::TestDiag - Log to Test::More's diagnostic output
 
   my $logger = Log::Dispatch->new(
       outputs => [
-          ['TestDiag', min_level=>'debug'],
+          ['TestDiag', min_level=>'debug', as_note=>0],
       ],
   );
 
@@ -51,9 +58,14 @@ using C<Test::More>'s diagnostic output.
 Constructs a new C<Log::Dispatch::TestDiag> object and returns it to the caller.
 Accepts standard C<Log::Dispatch::Output> parameters (e.g. C<min_level>).
 
+Also accepts an optional "C<as_note>" parameter, to indicate that output should
+be sent via C<Test::More::note()> instead of C<Test::More::diag()>.  Difference
+is that a "note" only appears in the verbose TAP stream and does not get shown
+when running under a test harness.
+
 =item log_message(%p)
 
-Logs the given message to C<Test::More::diag()>.
+Logs the given message.
 
 =back
 
@@ -63,13 +75,17 @@ Graham TerMarsch (cpan@howlingfrog.com)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2011, Graham TerMArsch.  All Rights Reserved.
+Copyright (C) 2011, Graham TerMarsch.  All Rights Reserved.
 
 This is free software, you can redistribute it and/or modify it under the
 Artistic-2.0 license.
 
 =head1 SEE ALSO
 
-L<Log::Dispatch>.
+=over
+
+=item L<Log::Dispatch>
+
+=back
 
 =cut
